# TouchUtilCollection
A collection of (hopefully) useful python-functions, methods and other trinkets.

Install via PIP, UV, Conda or whatever you like. 

## Layout
managing operators in your network.

## Network
Actual, like network as in TCP stuff...

## Operator
Manage operators!

## Parameter
Handle them parameters.

## Type
Typehinting helpers.